@@ -36,8 +36,8 @@ func newSecuritySchemesDiff() *SecuritySchemesDiff {
 	}
 }
 
-func getSecuritySchemesDiff(config *Config, state *state, securitySchemes1, securitySchemes2 openapi3.SecuritySchemes) (*SecuritySchemesDiff, error) {
-	diff, err := getSecuritySchemesDiffInternal(config, state, securitySchemes1, securitySchemes2)
+func getSecuritySchemesDiff(config *Config, securitySchemes1, securitySchemes2 openapi3.SecuritySchemes) (*SecuritySchemesDiff, error) {
+	diff, err := getSecuritySchemesDiffInternal(config, securitySchemes1, securitySchemes2)
 	if err != nil {
 		return nil, err
 	}
@@ -49,7 +49,7 @@ func getSecuritySchemesDiff(config *Config, state *state, securitySchemes1, secu
 	return diff, nil
 }
 
-func getSecuritySchemesDiffInternal(config *Config, state *state, securitySchemes1, securitySchemes2 openapi3.SecuritySchemes) (*SecuritySchemesDiff, error) {
+func getSecuritySchemesDiffInternal(config *Config, securitySchemes1, securitySchemes2 openapi3.SecuritySchemes) (*SecuritySchemesDiff, error) {
 
 	result := newSecuritySchemesDiff()
 
@@ -63,7 +63,7 @@ func getSecuritySchemesDiffInternal(config *Config, state *state, securityScheme
 			if err != nil {
 				return nil, err
 			}
-			diff, err := getSecuritySchemeDiff(config, state, value1, value2)
+			diff, err := getSecuritySchemeDiff(config, value1, value2)
 			if err != nil {
 				return nil, err
 			}
